summaryrefslogtreecommitdiffstats
path: root/kmymoney2/dialogs/kpayeereassigndlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/dialogs/kpayeereassigndlg.h')
-rw-r--r--kmymoney2/dialogs/kpayeereassigndlg.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/kmymoney2/dialogs/kpayeereassigndlg.h b/kmymoney2/dialogs/kpayeereassigndlg.h
index 3edab86..f0f21ac 100644
--- a/kmymoney2/dialogs/kpayeereassigndlg.h
+++ b/kmymoney2/dialogs/kpayeereassigndlg.h
@@ -23,8 +23,8 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qvaluelist.h>
-#include <qcheckbox.h>
+#include <tqvaluelist.h>
+#include <tqcheckbox.h>
// ----------------------------------------------------------------------------
// KDE Includes
@@ -42,9 +42,10 @@
class KPayeeReassignDlg : public KPayeeReassignDlgDecl
{
Q_OBJECT
+ TQ_OBJECT
public:
/** Default constructor */
- KPayeeReassignDlg( QWidget* parent = 0, const char* name = 0);
+ KPayeeReassignDlg( TQWidget* tqparent = 0, const char* name = 0);
/** Destructor */
~KPayeeReassignDlg();
@@ -53,12 +54,12 @@ public:
* This function sets up the dialog, lets the user select a payee and returns
* the id of the selected payee in the payeeslist.
*
* @param payeeslist reference to QValueList of MyMoneyPayee objects to be contained in the list
*
* @return Returns the id of the selected payee in the list or QString() if
* the dialog was aborted. QString() is also returned if the payeeslist is empty.
*/
- QString show(const QValueList<MyMoneyPayee>& payeeslist);
+ TQString show(const TQValueList<MyMoneyPayee>& payeeslist);
/**
* Returns true, if the names of the payees to be deleted should be copied
@@ -53,12 +54,12 @@ public:
* the id of the selected payee in the payeeslist.
*
- * @param payeeslist reference to QValueList of MyMoneyPayee objects to be contained in the list
+ * @param payeeslist reference to TQValueList of MyMoneyPayee objects to be contained in the list
*
@@ -53,12 +54,12 @@ public:
*
- * @return Returns the id of the selected payee in the list or QString() if
- * the dialog was aborted. QString() is also returned if the payeeslist is empty.
+ * @return Returns the id of the selected payee in the list or TQString() if
+ * the dialog was aborted. TQString() is also returned if the payeeslist is empty.
*/